@@ -160,6 +160,19 @@ class Newton:
         else:
             return res.text
  
+    def get_task_url(self,task_id: str=None,role: str=None):
+        api_url = f"{self.api_base}/task/url/{task_id}"
+
+        params = {}
+        if role is not None:
+            params["role"] = role
+
+        res = requests.get(api_url, params=params, headers=self.__headers)       
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
     def create_project(self, body: dict):
         api_url = f"{self.api_base}/project"
 
